@@ -11,7 +11,7 @@
 #GNU General Public License for more details.
 #You should have received a copy of the GNU Lesser General Public License
 #along with this program; if not, write to the Free Software
-#Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+#Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 from gi.repository import Atspi
 from pyatspi.utils import *
@@ -45,7 +45,7 @@ class Document(interface):
                 attribute, or an empty string if the attribute is unspecified
                 for the object.
                 """
-                return Atspi.Document.get_attribute_value(self.obj, key)
+                return Atspi.Document.get_document_attribute_value(self.obj, key)
 
         def getAttributes(self):
                 """
@@ -55,7 +55,7 @@ class Document(interface):
                 @return an AttributeSet containing the attributes of the document,
                 as name-value pairs.
                 """
-                ret = Atspi.Document.get_attributes(self.obj)
+                ret = Atspi.Document.get_document_attributes(self.obj)
                 return [key + ':' + value for key, value in ret.items()]
 
         def getLocale(self):
