@@ -11,7 +11,7 @@
 #GNU General Public License for more details.
 #You should have received a copy of the GNU Lesser General Public License
 #along with this program; if not, write to the Free Software
-#Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+#Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 #Portions of this code originally licensed and copyright (c) 2005, 2007
 #IBM Corporation under the BSD license, available at
@@ -339,7 +339,11 @@ def attributeListToHash(list):
         ret = dict()
         for item in list:
                 [key, val] = item.split(":")
-                ret[key] = val
+                val = val.replace(":", "\:")
+                if ret.__contains__(key):
+                    ret[key] = ret[key] + ":" + val
+                else:
+                    ret[key] = val
         return ret
 
 def hashToAttributeList(h):
